<?php
/**
*   FreshTheme Framework Admin
*   ---------------------------------------------------------------------------
*   @author 	: Rifki A.G
*   @version	: 1.2
*   @copyright	: Copyright (c) 2012, FreshThemes
*                 http://www.freshthemes.net
*                 http://www.rifki.net
*   @credits	: Devin Price, http://wptheming.com/
*                 WooThemes, http://www.woothemes.com/
*                 Gilles Vauvarin
*   --------------------------------------------------------------------------- */
 
/* 	Initialize framework.
 * 	------------------------------------------------------------------- */
	add_action('init', 'freshthemes_framework_init' );

	function freshthemes_framework_init() {
		if ( current_user_can('edit_theme_options') ) {
			add_action('admin_menu', 'freshthemes_admin_menus');
			add_action('wp_before_admin_bar_render', 'freshthemes_adminbar_render');
			add_action('admin_init', 'freshthemes_admin_init');
			add_action('admin_init', 'freshthemes_mlu_init');
		}
	}

/*	Load sanitazion 
 *	------------------------------------------------------------------- */
	add_action('init', 'freshthemes_load_sanitization' );

	function freshthemes_load_sanitization() {
		require_once ('sanitize.php');
	}
	
/*	Load sidebar manager 
 *	------------------------------------------------------------------- */
	add_action('init', 'freshthemes_load_sidebar_manager' );

	function freshthemes_load_sidebar_manager() {
		require_once ('sidebar-manager.php');
	}
	
/*	Load backup 
 *	------------------------------------------------------------------- */
	add_action('init', 'freshthemes_load_backup' );

	function freshthemes_load_backup() {
		require_once ('backup.php');
	}
	
/* 	Admin initialize. 
 * 	------------------------------------------------------------------- */
 	function freshthemes_admin_init() {
		
		/* Include required files */
		require_once ('interface.php');
		require_once ('media-uploader.php');
		require_once (THEME_PATH . '/functions/theme-options.php');
		
		/* Load Settings */
		$freshthemes_settings = get_option('freshthemes');
		
		/* Updates the unique option id in the database if it has changed */
		if ( function_exists( 'freshthemes_option_name' ) ) {
			freshthemes_option_name();
		}
		
		/* Gets the unique id, returning a default if it isn't defined */
		if ( isset($freshthemes_settings['id']) ) {
			$option_name = $freshthemes_settings['id'];
		}
		else {
			$option_name = 'freshthemes';
		}
		
		/* If the option has no saved data, load the defaults */
		if ( ! get_option($option_name) ) {
			freshthemes_setdefaults();
		}
		
		/* Registers the settings fields and callback */
		if (!isset( $_POST['freshthemes-backup-import'] )) {
			register_setting( 'freshthemes', $option_name, 'freshthemes_validate' );
		}
		
		/* Change the capability required to save the 'optionsframework' options group. */
		add_filter( 'option_page_capability_freshthemes', 'freshthemes_page_capability' );
	}
	
/* 	Check capability 
 * 	------------------------------------------------------------------- */
	function freshthemes_page_capability( $capability ) {
		return 'edit_theme_options';
	}
	
/* 	Adds default values
 * 	------------------------------------------------------------------- */
	function freshthemes_setdefaults() {
		$freshthemes_settings = get_option('freshthemes');
		$option_name = $freshthemes_settings['id'];
	
		if ( isset($freshthemes_settings['knownoptions']) ) {
			$knownoptions =  $freshthemes_settings['knownoptions'];
			if ( !in_array($option_name, $knownoptions) ) {
				array_push( $knownoptions, $option_name );
				$freshthemes_settings['knownoptions'] = $knownoptions;
				update_option('freshthemes', $freshthemes_settings);
			}
		} 
		else {
			$newoptionname = array($option_name);
			$freshthemes_settings['knownoptions'] = $newoptionname;
			update_option('freshthemes', $freshthemes_settings);
		}
	
		$options = freshthemes_options();
		$values = freshthemes_get_default_values();
	
		if ( isset($values) ) {
			add_option( $option_name, $values );
		}
	}
	
/* 	Add admin menus. 
 * 	------------------------------------------------------------------- */
	if ( !function_exists( 'freshthemes_admin_menus' ) ) {
		function freshthemes_admin_menus() {
			$freshthemes_admin_page = add_menu_page(
				__('Fresh Panel', THEME_FX ), 
				__('Fresh Panel', THEME_FX), 
				'edit_theme_options', 
				'fresh-panel', 
				'freshthemes_front_end', 
				THEME_DIR . '/functions/framework/images/icon.png'
			);
			
			add_submenu_page(
				'fresh-panel', 
				__('گزینه‌های پوسته', THEME_FX ), 
				__('گزینه‌های پوسته', THEME_FX ), 
				'manage_options', 
				'fresh-panel', 
				'freshthemes_front_end'
			);
			
			add_action('admin_enqueue_scripts', 'freshthemes_load_scripts');
			add_action('admin_print_styles-' . $freshthemes_admin_page, 'freshthemes_load_styles' );
		}
	}
	
/* 	Render admin bar menu. 
 * 	------------------------------------------------------------------- */
 	function freshthemes_adminbar_render() {
		global $wp_admin_bar;
		
		$wp_admin_bar->add_menu( array(
			'id' => 'freshthemes_fresh_panel',
			'title' => __( '<span class="ab-icon"><img src="'.THEME_DIR .'/functions/framework/images/adminbar-icon.png" style="position:absolute;" alt="Visit Site" title="Visit Site" /></span><span class="ab-label">Fresh Panel</span>', THEME_FX ),
			'href' => admin_url( 'admin.php?page=fresh-panel' )
		));
		
		$wp_admin_bar->add_menu( array(
			'id' => 'freshthemes_theme_options',
			'title' => __( 'تنظیمات پوسته', THEME_FX ),
			'href' => admin_url( 'admin.php?page=fresh-panel' ),
			'parent'=>'freshthemes_fresh_panel'
		));
		
		$wp_admin_bar->add_menu( array(
			'id' => 'freshthemes_sidebar_manager',
			'title' => __( 'مدیریت ستون‌کناری', THEME_FX ),
			'href' => admin_url( 'admin.php?page=fresh-sidebar-manager' ),
			'parent'=>'freshthemes_fresh_panel'
		));
		
		$wp_admin_bar->add_menu( array(
			'id' => 'freshthemes_theme_backup_options',
			'title' => __( 'تنظیمات پشتیبان', THEME_FX ),
			'href' => admin_url( 'admin.php?page=fresh-panel-backup' ),
			'parent'=>'freshthemes_fresh_panel'
		));
	}
	
/*	Loads the CSS 
 *	------------------------------------------------------------------- */
	function freshthemes_load_styles() {
		wp_enqueue_style('admin-style', THEME_DIR . '/functions/framework/stylesheets/admin-style.css', array(), '1.2' );
		wp_enqueue_style('admin-color-picker', THEME_DIR . '/functions/framework/stylesheets/colorpicker.css', array(), '1.2' );
	}	

/*	Loads the javascript 
 *	------------------------------------------------------------------- */
	function freshthemes_load_scripts($hook) {
		if ( 'toplevel_page_fresh-panel' != $hook )
        return;
		
		// Enqueued scripts
		wp_enqueue_script('custom-color-picker', THEME_DIR . '/functions/framework/javascripts/colorpicker.js', array(), '1.2', false );
		wp_enqueue_script('admin-js', THEME_DIR . '/functions/framework/javascripts/admin.js', array(), '1.2', false );
	
		// Inline scripts from options-interface.php
		add_action('admin_head', 'freshthemes_admin_head');
	}
	
	// Hook to add custom scripts
	function freshthemes_admin_head() {
		do_action( 'freshthemes_custom_scripts' );
	}
	
/*	FreshThemes front end 
 *	------------------------------------------------------------------- */
	if ( !function_exists( 'freshthemes_front_end' ) ) :
	function freshthemes_front_end() { 
		settings_errors(); 
		
		$store_url = 'http://bigtheme.ir/category/featured-product/';
		$profile_url = 'http://bigtheme.ir/%D9%BE%D8%B4%D8%AA%DB%8C%D8%A8%D8%A7%D9%86%DB%8C/';
		?>
		
		<div id="freshthemes" class="wrap">
			<form action="options.php" method="post">
				<div id="freshthemes-header">
					<div class="logo">
					</div>
					
					<div class="sep"></div>
					
					<div class="themeinfo">
						<span class="themename"><?php echo THEME_NAME; ?></span>
						<span class="themeversion">نسخه: <?php echo THEME_VERSION; ?></span>
					</div>
					
					<div class="sep"></div>
					
					<div class="extralinks">
						<a class="support" href="<?php echo $profile_url; ?>" target="_blank">پشتیبانی</a>
						<a class="store" href="<?php echo $store_url; ?>" target="_blank">فروشگاه</a>
					</div>
				</div>
				
				<div id="freshthemes-main">
					<div id="freshthemes-tabs">
						<div class="shadow"></div>
						<ul>
							<?php echo freshthemes_menu_tabs(); ?>
						</ul>
					</div>
					
					<div id="freshthemes-content">
						<?php settings_fields('freshthemes'); ?>
						<?php freshthemes_fields(); ?>
					</div>
					
					<div class="clear"></div>
				</div>
				
				<div id="freshthemes-footer">
					<div class="thanks" style="float:left">
						&copy; بیگ تم - <?php printf( __('مرجع <a href="%s" target="_blank">پوسته‌های وردپرس</a>', THEME_FX ), $store_url ); ?>
					</div>
					
					<div style="float:right">
					<input type="submit" class="button reset-button button-secondary" name="reset" value="<?php esc_attr_e( 'بازگردانی به حالت پیشفرض', THEME_FX ); ?>" onclick="return confirm( '<?php print esc_js( __( 'برای بازگردانی روی ok کلیک کنید. همه تنظیمات شما از دست خواهد رفت!', THEME_FX ) ); ?>' );" />
					<input type="submit" class="button button-primary" name="update" value="<?php esc_attr_e( 'ذخیره گزینه‌ها', THEME_FX ); ?>" />
					</div>
					
					<div class="clear"></div>
				</div>
			</form>
		</div>
		
		<?php
	}
	endif; 
	
/*	Validate Options
 *	------------------------------------------------------------------- */
	function freshthemes_validate( $input ) {

		/* Restore Defaults */
		if ( isset( $_POST['reset'] ) ) {
			add_settings_error( 'fresh-panel', 'restore_defaults', __( 'گزینه‌های پیشفرض بازگردانی شده‌اند.', THEME_FX ), 'updated fade' );
			return freshthemes_get_default_values();
		}
		
		/* Update Settings */
		$clean = array();
		$options = freshthemes_options();
		
		foreach ( $options as $option ) {
			if ( ! isset( $option['id'] ) ) {
				continue;
			}
			if ( ! isset( $option['type'] ) ) {
				continue;
			}
			$id = preg_replace( '/[^a-zA-Z0-9._\-]/', '', strtolower( $option['id'] ) );
	
			// Set checkbox to false if it wasn't sent in the $_POST
			if ( 'checkbox' == $option['type'] && ! isset( $input[$id] ) ) {
				$input[$id] = false;
			}
	
			// Set each item in the multicheck to false if it wasn't sent in the $_POST
			if ( 'multicheck' == $option['type'] && ! isset( $input[$id] ) ) {
				foreach ( $option['options'] as $key => $value ) {
					$input[$id][$key] = false;
				}
			}
	
			// For a value to be submitted to database it must pass through a sanitization filter
			if ( has_filter( 'freshthemes_sanitize_' . $option['type'] ) ) {
				$clean[$id] = apply_filters( 'freshthemes_sanitize_' . $option['type'], $input[$id], $option );
			}
		}
		
		// Hook to run after validation
		do_action( 'freshthemes_after_validate', $clean );
		
		return $clean;
	}
	
/*	Display message when options have been saved
 *	------------------------------------------------------------------- */
	function freshthemes_save_options_notice() {
		add_settings_error( 'fresh-panel', 'save_options', __( 'گزینه‌ها ذخیره شده‌اند.', THEME_FX ), 'updated fade' );
	}
	
	add_action( 'freshthemes_after_validate', 'freshthemes_save_options_notice' );
	
/*	Get default values
 *	------------------------------------------------------------------- */
	function freshthemes_get_default_values() {
		$output = array();
		$config = freshthemes_options();
		
		foreach ( (array) $config as $option ) {
			if ( ! isset( $option['id'] ) ) {
				continue;
			}
			if ( ! isset( $option['std'] ) ) {
				continue;
			}
			if ( ! isset( $option['type'] ) ) {
				continue;
			}
			if ( has_filter( 'freshthemes_sanitize_' . $option['type'] ) ) {
				$output[$option['id']] = apply_filters( 'freshthemes_sanitize_' . $option['type'], $option['std'], $option );
			}
		}
		
		return $output;
	}
	
/*	Get option
 * 	------------------------------------------------------------------- */
	if ( ! function_exists( 'ft_get_option' ) ) {
		function ft_get_option( $name, $default = false ) {
			$prefix = THEME_FX . '_';
			$config = get_option( 'freshthemes' );

			$id = $prefix . $name;
		
			if ( ! isset( $config['id'] ) ) {
				return $default;
			}

			$options = get_option( $config['id'] );

			if ( isset( $options[$id] ) ) {
				return $options[$id];
			}

			return $default;
		}
	}
	
/*	Create custom JS and CSS files
 *	------------------------------------------------------------------- */
	function freshthemes_create_custom_js_css( $source, $file) {
		$directory = THEME_PATH . '/functions/framework/frontend/';
		$source_file = $directory . $source;
		$file = $directory . $file;
		
		if ( file_exists( $source_file ) ) {
			ob_start();
			require($source_file);
			$output = ob_get_clean();
			file_put_contents($file, $output, LOCK_EX);
		}
	}
	
 	freshthemes_create_custom_js_css( 'frontend.css.php', 'custom-style.css');
 	freshthemes_create_custom_js_css( 'frontend.js.php', 'custom-script.js');
	
/*	Google fonts array
 *	------------------------------------------------------------------- */
	function freshthemes_typography_get_google_fonts() {
		$google_faces = array(
			'Abel, sans-serif' => 'Abel',
			'Arimo, san-serif' => 'Arimo',
			'Arvo, serif' => 'Arvo',
			'Asap, sans-serif' => 'Asap',
			'Bitter, serif' => 'Bitter',
			'Cabin, sans-serif' => 'Cabin',
			'Cantarell, sans-serif' => 'Cantarell',
			'Carrois Gothic, sans-serif' => 'Carrois Gothic',
			'Cuprum, sans-serif' => 'Cuprum',
			'Droid Sans, sans-serif' => 'Droid Sans',
			'Droid Serif, serif' => 'Droid Serif',
			'Josefin Sans, sans-serif' => 'Josefin Sans',
			'Kreon, serif' => 'Kreon',
			'Lato, sans-serif' => 'Lato',
			'Lora, serif' => 'Lora',
			'Lobster, cursive' => 'Lobster',
			'Merriweather, serif' => 'Merriweather',
			'Nunito, sans-serif' => 'Nunito',
			'Nobile, sans-serif' => 'Nobile',
			'Open Sans, sans-serif' => 'Open Sans',
			'Oswald, sans-serif' => 'Oswald',
			'Philosopher, sans-serif' => 'Philosopher',
			'Play, sans-serif' => 'Play',
			'PT Sans, sans-serif' => 'PT Sans',
			'PT Serif, serif' => 'PT Serif',
			'Questrial, sans-serif' => 'Questrial',
			'Rokkitt, serif' => 'Rokkitt',
			'Source Sans Pro, sans-serif' => 'Source Sans Pro',
			'Ubuntu, sans-serif' => 'Ubuntu',
			'Vollkorn, serif' => 'Vollkorn',
			'Yanone Kaffeesatz, sans-serif' => 'Yanone Kaffeesatz',
		);
		
		return $google_faces;
	}

/*	OS fonts array
 *	------------------------------------------------------------------- */
	function freshthemes_typography_get_os_fonts() {
		$os_faces = array(
			'Arial, Helvetica, sans-serif' => 'Arial',
			'Cambria, Georgia, serif' => 'Cambria',
			'Garamond, "Hoefler Text", Times New Roman, Times, serif' => 'Garamond',
			'Georgia, Times New Roman, Times, serif' => 'Georgia',
			'"Helvetica Neue", Helvetica, sans-serif' => 'Helvetica Neue',
			'"Lucida Sans Unicode", Arial, Helvetica, sans-serif' => 'Lucida Sans Unicode',
			'Verdana, Geneva, sans-serif' => 'Verdana',
			'Tahoma, Geneva, sans-serif' => 'Tahoma'
		);
		
		return $os_faces;
	}