<?php
/**
 *	WooFramework Media Library-driven AJAX File Uploader Module
 * 	---------------------------------------------------------------------------
 *
 *	The code below is designed to work as a part of the WooFramework Media Library-driven
 *	AJAX File Uploader Module. It is included only on screens where this module is used.
 *
 *	@author 	: WooFramework
 *	@link		: http://www.woothemes.com/
 *	@copyright	: Copyright (c) 2010, http://www.woothemes.com/
 *
 * 	Used with (very) slight modifications for Options Framework and FreshThemes Framework.
 *	--------------------------------------------------------------------------- */

/*	Load additional css and js
 *	------------------------------------------------------------------- */
	if ( is_admin() ) {
		$freshthemes_admin_page = 'toplevel_page_fresh-panel';
		add_action( "admin_print_styles-$freshthemes_admin_page", 'freshthemes_mlu_css', 0 );
		add_action( "admin_print_scripts-$freshthemes_admin_page", 'freshthemes_mlu_js', 0 );	
	}
	
/*	Setting up custom post type
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_mlu_init' ) ) {
		function freshthemes_mlu_init () {
			register_post_type( 'freshthemes', array(
				'labels' => array(
					'name' => __( 'مدیای گزینه‌های پوسته', THEME_FX ),
				),
				'show_ui' => false,
				'capability_type' => 'post',
				'hierarchical' => false,
				'rewrite' => false,
				'supports' => array( 'title', 'editor' ), 
				'query_var' => false,
				'can_export' => true,
				'show_in_nav_menus' => false,
				'public' => false
			) );
		}
	}
	
/*	Load Tickbox css and properties
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_mlu_css' ) ) {
		function freshthemes_mlu_css () {
			$_html = '';
			$_html .= '<link rel="stylesheet" href="' . site_url() . '/' . WPINC . '/js/thickbox/thickbox.css" type="text/css" media="screen" />' . "\n";
			$_html .= '<script type="text/javascript">
			var tb_pathToImage = "' . site_url() . '/' . WPINC . '/js/thickbox/loadingAnimation.gif";
			var tb_closeImage = "' . site_url() . '/' . WPINC . '/js/thickbox/tb-close.png";
			</script>' . "\n";
			echo $_html;
		}

	}

/*	Load media uploader js
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_mlu_js' ) ) {
		function freshthemes_mlu_js () {
			wp_register_script( 'freshthemes-medialibrary-uploader', THEME_DIR .'/functions/framework/javascripts/media-uploader.js', array( 'jquery', 'thickbox' ) );
			wp_enqueue_script( 'freshthemes-medialibrary-uploader' );
			wp_enqueue_script( 'media-upload' );
		}
	}

/*	Uploader field
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_medialibrary_uploader' ) ) {
		function freshthemes_medialibrary_uploader( $_id, $_value, $_mode = 'full', $_desc = '', $_postid = 0, $_name = '') {
			$freshthemes_settings = get_option('freshthemes');
		
			// Gets the unique option id
			$option_name = $freshthemes_settings['id'];
			
			$output = '';
			$id = '';
			$class = '';
			$int = '';
			$value = '';
			$name = '';
		
			$id = strip_tags( strtolower( $_id ) );
		
			// Change for each field, using a "silent" post. If no post is present, one will be created.
			$int = freshthemes_mlu_get_silentpost( $id );
		
			// If a value is passed and we don't have a stored value, use the value that's passed through.
			if ( $_value != '' && $value == '' ) {
				$value = $_value;
			}
			if ($_name != '') {
				$name = $option_name.'['.$id.']['.$_name.']';
			}
			else {
				$name = $option_name.'['.$id.']';
			}
			if ( $value ) {
				$class = ' has-file'; 
			}
			
			$input_type = 'text';
			if ( $_mode == 'mini' )
			$input_type = 'hidden';
			
			$output .= '<input id="' . $id . '" class="freshthemes-input upload' . $class . '" type="'.$input_type.'" name="'.$name.'" value="' . $value . '"' .( $_desc != '' ? ' placeholder="'.$_desc.'"' : '' ) .' />' . "\n";
			$output .= '<input id="upload_' . $id . '" class="upload_button button" type="button" value="' . __( 'بارگذاری', THEME_FX ) . '" rel="' . $int . '" />' . "\n";
		
			//if ( $_desc != '' ) {
				//$output .= '<span class="freshthemes_metabox_desc">' . $_desc . '</span>' . "\n";
			//}
		
			$output .= '<div class="screenshot' .( $value != '' ? '' : ' empty' ) .'" id="' . $id . '_image">' . "\n";
		
			if ( $value != '' ) { 
				$remove = '<a href="#" class="mlu_remove" title="Delete this image">X</a>';
				$image = preg_match( '/(^.*\.jpg|jpeg|png|gif|ico*)/i', $value );
				if ( $image ) {
					$output .= '<img src="' . $value . '" alt="" />'.$remove.'';
				} else {
					$parts = explode( "/", $value );
					for( $i = 0; $i < sizeof( $parts ); ++$i ) {
						$title = $parts[$i];
					}

					// No output preview if it's not an image.			
					$output .= '';
			
					// Standard generic output if it's not an image.	
					$title = __( 'مشاهده فایل', THEME_FX );
					$output .= '<div class="no_image"><span class="file_link"><a href="' . $value . '" target="_blank" rel="external">'.$title.'</a></span>' . $remove . '</div>';
				}	
			}
		
			$output .= '</div>' . "\n";
			return $output;
		}	
	}

/*	Uses "silent" posts in the database to store relationships for images.
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_mlu_get_silentpost' ) ) {
		function freshthemes_mlu_get_silentpost ( $_token ) {
			global $wpdb;
			$_id = 0;
	
			// Check if the token is valid against a whitelist.
			// $_whitelist = array( 'freshthemes_logo', 'freshthemes_custom_favicon', 'freshthemes_ad_top_image' );
			// Sanitise the token.
			$_token = strtolower( str_replace( ' ', '_', $_token ) );
		
			// if ( in_array( $_token, $_whitelist ) ) {
			if ( $_token ) {
			
				// Tell the function what to look for in a post.
				$_args = array( 'post_type' => 'freshthemes', 'post_name' => 'freshthemes-' . $_token, 'post_status' => 'draft', 'comment_status' => 'closed', 'ping_status' => 'closed' );
			
				// Look in the database for a "silent" post that meets our criteria.
				$query = 'SELECT ID FROM ' . $wpdb->posts . ' WHERE post_parent = 0';
				foreach ( $_args as $k => $v ) {
					$query .= ' AND ' . $k . ' = "' . $v . '"';
				} // End FOREACH Loop
			
				$query .= ' LIMIT 1';
				$_posts = $wpdb->get_row( $query );
			
				// If we've got a post, loop through and get it's ID.
				if ( count( $_posts ) ) {
					$_id = $_posts->ID;
				} else {
			
					// If no post is present, insert one.
					// Prepare some additional data to go with the post insertion.
					$_words = explode( '_', $_token );
					$_title = join( ' ', $_words );
					$_title = ucwords( $_title );
					$_post_data = array( 'post_title' => $_title );
					$_post_data = array_merge( $_post_data, $_args );
					$_id = wp_insert_post( $_post_data );
				}	
			}
			return $_id;
		}
	}

/*	Trigger code inside the Media Library popup.
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_mlu_insidepopup' ) ) {
		function freshthemes_mlu_insidepopup () {
			if ( isset( $_REQUEST['is_freshthemes'] ) && $_REQUEST['is_freshthemes'] == 'yes' ) {
				add_action( 'admin_head', 'freshthemes_mlu_js_popup' );
				add_filter( 'media_upload_tabs', 'freshthemes_mlu_modify_tabs' );
			}
		}
	}

	if ( ! function_exists( 'freshthemes_mlu_js_popup' ) ) {
		function freshthemes_mlu_js_popup () {
			$_freshthemes_title = $_REQUEST['freshthemes_title'];
			if ( ! $_freshthemes_title ) { $_freshthemes_title = 'file'; } // End IF Statement
			?>
			<script type="text/javascript">
			<!--
			jQuery(function($) {
		
				jQuery.noConflict();
				
				// Change the title of each tab to use the custom title text instead of "Media File".
				$( 'h3.media-title' ).each ( function () {
					var current_title = $( this ).html();
					var new_title = current_title.replace( 'media file', '<?php echo $_freshthemes_title; ?>' );
					$( this ).html( new_title );
		
				});
		
				// Change the text of the "Insert into Post" buttons to read "Use this File".
				$( '.savesend input.button[value*="Insert into Post"], .media-item #go_button' ).attr( 'value', 'Use this File' );
		
				// Hide the "Insert Gallery" settings box on the "Gallery" tab.
				$( 'div#gallery-settings' ).hide();
		
				// Preserve the "is_optionsframework" parameter on the "delete" confirmation button.
				$( '.savesend a.del-link' ).click ( function () {
					var continueButton = $( this ).next( '.del-attachment' ).children( 'a.button[id*="del"]' );
					var continueHref = continueButton.attr( 'href' );
					continueHref = continueHref + '&is_freshthemes=yes';
					continueButton.attr( 'href', continueHref );
				});
			});
			-->
			</script>
			<?php
		}
	}

/*	Triggered inside the Media Library popup to modify the title of the "Gallery" tab.
 *	------------------------------------------------------------------- */
	if ( ! function_exists( 'freshthemes_mlu_modify_tabs' ) ) {
		function freshthemes_mlu_modify_tabs ( $tabs ) {
			$tabs['gallery'] = str_replace( __( 'گالری', THEME_FX ), __( 'بارگذاری‌های قبلی', THEME_FX ), $tabs['gallery'] );
			return $tabs;
		}
	}