<?php

/* 	Add support for a variety of post formats
 *	--------------------------------------------------------------------------- */
	add_theme_support('post-formats', array( 'image', 'gallery', 'video' ));

/* 	Support for editor style
 *	--------------------------------------------------------------------------- */
	add_editor_style('editor-style.css');
	
/* 	Automatic feed links
 *	--------------------------------------------------------------------------- */
	if( ft_get_option('feed_links') ) add_theme_support( 'automatic-feed-links' );
	
/* 	Add support for featured image. 
 *	--------------------------------------------------------------------------- */
	if ( function_exists('add_theme_support') ) {
		add_theme_support('post-thumbnails'); 
	}
	
/*	Add default image sizes
 *	--------------------------------------------------------------------------- */
	if ( function_exists( 'add_image_size' ) ) { 
		add_image_size( 'content-image', 465, 9999 );
		add_image_size( 'fullwidth-image', 960, 9999 );
	}
	
/* 	Register WP nav menus
 *	--------------------------------------------------------------------------- */
	if ( function_exists('register_nav_menus') ) { // make sure your WordPress version supported for wp_nav_menus.
		register_nav_menus(
			array(
				'top_menu' => 'Top Menu', // register top nav menu.
				'primary_menu' => 'Primary Menu', // register primary nav menu.
			)
		);
	}
	
/*	Register Widgets Area
 *	--------------------------------------------------------------------------- */	
	add_action( 'widgets_init', 'freshthemes_widgets_init' );
	
	function freshthemes_widgets_init() {
		$freshthemes_sidebars = get_option('freshthemes_sidebars');
		
		if (!$freshthemes_sidebars) {
			$freshthemes_sidebars = array( 'active' => array() );
		}
		
		$freshthemes_sidebars = $freshthemes_sidebars['active'];
		
		register_sidebar( array(
			'name'			=> __( 'Right Sidebar', THEME_FX ),
			'id'			=> 'left-sidebar',
			'description'	=> __( 'مکان ابزارک ستون کناری راست', THEME_FX ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="heading"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Left Sidebar', THEME_FX ),
			'id'			=> 'right-sidebar',
			'description'	=> __( 'مکان ابزارک ستون کناری چپ', THEME_FX ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="heading"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget One', THEME_FX ),
			'id'			=> 'sidebar-footer-1',
			'description'	=> __( 'The sidebar widget area for your site footer', THEME_FX ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="heading"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget Two', THEME_FX ),
			'id'			=> 'sidebar-footer-2',
			'description'	=> __( 'The sidebar widget area for your site footer', THEME_FX ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="heading"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget Three', THEME_FX ),
			'id'			=> 'sidebar-footer-3',
			'description'	=> __( 'The sidebar widget area for your site footer', THEME_FX ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="heading"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		register_sidebar( array(
			'name'			=> __( 'Footer Widget Four', THEME_FX ),
			'id'			=> 'sidebar-footer-4',
			'description'	=> __( 'The sidebar widget area for your site footer', THEME_FX ),
			'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
			'after_widget'	=> '</aside>',
			'before_title'	=> '<h3 class="heading"><span>',
			'after_title'	=> '</span></h3>',
		));
		
		foreach( $freshthemes_sidebars as $widget ) {
			$temp_widget = array(  
				'name' 			=> $widget,
				'description' 	=> __( 'Dynamic sidebar', THEME_FX),
				'before_widget'	=> '<aside id="%1$s" class="widget %2$s clearfix">',
				'after_widget'	=> '</aside>',
				'before_title'	=> '<h3 class="heading"><span>',
				'after_title'	=> '</span></h3>',
			);
	
			register_sidebar( $temp_widget );
		}
	}
	
/* 	Load Theme Styles
 *	--------------------------------------------------------------------------- */	
	function freshthemes_theme_styles() {
		
		/* Google fonts array */
		$google_fonts = array_keys( freshthemes_typography_get_google_fonts() );
			
		/* Define all the options that possibly have a unique Google font */
		$body_font = ft_get_option('body_font', 'Arial, Helvetica, san-serif');
		$heading_font = ft_get_option('heading_font', 'Arial, Helvetica, san-serif');
		$menu_nav_font = ft_get_option('menu_nav_font', 'Arial, Helvetica, san-serif');
	
		/* Get the font face for each option and put it in an array */
		$selected_fonts = array(
			$body_font['face'],
			$heading_font['face'],
			$menu_nav_font['face'],
		);
		
		/* Remove any duplicates in the list */
		$selected_fonts = array_unique($selected_fonts);
		
		/* If it is a Google font, go ahead and call the function to enqueue it */
		foreach ( $selected_fonts as $font ) {
			if ( in_array( $font, $google_fonts ) ) {
				freshthemes_typography_enqueue_google_font($font);
			}
		}
		
		// Register our styles.
		wp_register_style('main', get_stylesheet_uri(), false, THEME_VERSION, 'all');
		wp_register_style('prettyPhoto', THEME_DIR . '/stylesheets/prettyPhoto.css', false, THEME_VERSION, 'all');
		wp_register_style('responsive', THEME_DIR . '/stylesheets/responsive.css', false, THEME_VERSION, 'all');
		wp_register_style('custom-style', THEME_DIR . '/functions/framework/frontend/custom-style.css', false, filemtime(THEME_PATH . '/functions/framework/frontend/custom-style.css'), 'all');
		
		// Enqueue them.
		wp_enqueue_style('main');
		wp_enqueue_style('custom-style');
		wp_enqueue_style('prettyPhoto');
		wp_enqueue_style('responsive');
	}
	
	add_action('wp_enqueue_scripts', 'freshthemes_theme_styles');
	
/*	Load Theme Scripts
 *	--------------------------------------------------------------------------- */	
	function freshthemes_theme_scripts() {
		
		// Register our scripts.
		wp_register_script('plugins', THEME_DIR . '/javascripts/plugins.js', array('jquery'), THEME_VERSION, false );
		wp_register_script('sharrre', THEME_DIR . '/javascripts/jquery.sharrre-1.3.3.min.js', false, THEME_VERSION, false );
		wp_register_script('theme-script', THEME_DIR . '/javascripts/theme-script.js', false, THEME_VERSION, true );
		wp_register_script('custom-script', THEME_DIR . '/functions/framework/frontend/custom-script.js', false, filemtime(THEME_PATH . '/functions/framework/frontend/custom-script.js'), true);
		
		// Enqueue them then.
		wp_enqueue_script('plugins');
		wp_enqueue_script('sharrre');
		wp_enqueue_script('theme-script');
		wp_enqueue_script('custom-script');
		
		/* If is single and comment is allowed */
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
	
	add_action('wp_enqueue_scripts', 'freshthemes_theme_scripts');
	
/*	Modify the excerpt lenght
 *	--------------------------------------------------------------------------- */	
	function freshthemes_excerpt_length( $length ) {
		return 19;
	}
	add_filter( 'excerpt_length', 'freshthemes_excerpt_length' );
	
/*	Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis.
 *	--------------------------------------------------------------------------- */	
	function freshthemes_auto_excerpt_more( $more ) {
		return ' &hellip;';
	}
	
	add_filter( 'excerpt_more', 'freshthemes_auto_excerpt_more' );
	
/* 	Clean active menus
 *	--------------------------------------------------------------------------- */
	function freshthemes_clean_active_menu($css_classes, $item) {
		$css_classes = str_replace('current_page_item', 'active', $css_classes);
		$css_classes = str_replace('current-menu-item', 'active', $css_classes);
		/*$css_classes = str_replace('current-post-ancestor', 'active', $css_classes);
		$css_classes = str_replace('current-menu-parent', 'active', $css_classes);
		$css_classes = str_replace('current-menu-ancestor', 'active', $css_classes);*/
		
		return $css_classes;
	}
	
	add_filter('nav_menu_css_class', 'freshthemes_clean_active_menu', 10, 2);
	
/*	Modify the tag cloud widget
 *	--------------------------------------------------------------------------- */
	function freshthemes_tag_cloud_args(){
		return 'smallest=11&largest=11&number=25&orderby=name&unit=px';
	}
	
	add_filter( 'widget_tag_cloud_args', 'freshthemes_tag_cloud_args' );
	
/*	Function add browser classes into <body> tag
 *	---------------------------------------- */
	function freshthemes_browser_body_class($class) {
		global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
	
		if($is_lynx) 
		$class[] = 'lynx';
		elseif($is_gecko) 
		$class[] = 'gecko';
		elseif($is_opera) 
		$class[] = 'opera';
		elseif($is_NS4) 
		$class[] = 'ns4';
		elseif($is_safari) 
		$class[] = 'safari';
		elseif($is_chrome) 
		$class[] = 'chrome';
		elseif($is_IE) 
		$class[] = 'ie';
		elseif($is_iphone) 
		$class[] = 'iphone';
		else 
		$class[] = 'unknown';
		
		return $class;
	}
	
	add_filter('body_class', 'freshthemes_browser_body_class');	
	

	
/*	Insert Default Pages (called from functions.php)
 *	--------------------------------------------------------------------------- */
 	function freshthemes_insert_default_pages() {
		global $wpdb;
		
		$sql = "SELECT ID FROM $wpdb->posts WHERE post_name = %s LIMIT 1";
		$sql_template = "SELECT ID FROM $wpdb->posts INNER JOIN $wpdb->postmeta ON $wpdb->posts.ID = $wpdb->postmeta.post_id WHERE post_name = %s OR ($wpdb->postmeta.meta_key = '_wp_page_template' AND $wpdb->postmeta.meta_value = %s) LIMIT 1";
		
		// Home Page
		$pagefound = $wpdb->get_var( $wpdb->prepare($sql_template, 'home', 'template-home.php') );

		if( $wpdb->num_rows == 0 ) {
			
			$my_page = array(
				'post_status' => 'publish',
				'post_type' => 'page',
				'post_author' => 1,
				'post_name' => 'home',
				'post_title' => 'Home'
			);
	
			// Insert the page into the database
			$page_id = wp_insert_post($my_page);
	
			// Assign the page template to the new page
			update_post_meta($page_id, '_wp_page_template', 'template-home.php');

		}
		
		// Blog Page
		$pagefound = $wpdb->get_var( $wpdb->prepare($sql_template, 'news') );

		if( $wpdb->num_rows == 0 ) {
			
			$my_page = array(
				'post_status' => 'publish',
				'post_type' => 'page',
				'post_author' => 1,
				'post_name' => 'news',
				'post_title' => 'News'
			);
	
			// Insert the page into the database
			$page_id = wp_insert_post($my_page);

		}
	}
	
/* 	Print image gallery
 * 	------------------------------------------------------------------------------------------------------ */	
	function freshthemes_print_gallery_images($args = '') {
		global $post;
		
		/* default args */
		$defaults = array (
			'ID' => $post->ID,
			'count' => -1,
			'before' => '',
			'after' => '',
			'size' => 'full',
			'caption' => false,
			'lightbox' => false
		);
		
		$x = wp_parse_args ( $args, $defaults );
		$postID = $x['ID'];
		$count = $x['count'];
		$before = $x['before'];
		$after = $x['after'];
		$size = $x['size'];
		$caption = $x['caption'];
		$lightbox = $x['lightbox'];
		
		$args = array(
			'numberposts' => $count,
			'order'=> 'DESC',
			'post_mime_type' => 'image',
			'post_parent' => $postID,
			'post_status' => null,
			'post_type' => 'attachment'
		);
		

		$attachments = get_children( $args );
		
		$output = '';
		
		if ($attachments) {
			foreach($attachments as $attachment) {
				$output .= $before;
				if($lightbox != false) :
					$output .= '<a href="'. $attachment->guid .'" title="'.$attachment->post_title.'" class="prettyPhoto">' . wp_get_attachment_image( $attachment->ID, $size ) . '</a>';
				else :
					$output .= '<a href="'. $attachment->guid .'" title="'.$attachment->post_title.'">' . wp_get_attachment_image( $attachment->ID, $size ) . '</a>';
				endif;
				
				if($caption != false) :
					if($attachment->post_title != '') :
						$output .= '<div class="flex-caption">'. $attachment->post_title .'</div>';
					endif;
				endif;
				$output .= $after;
			}
			
			return $output;
		}
	}
	
/* 	Print loop
 * 	------------------------------------------------------------------------------------------------------ */	
	function freshthemes_print_loop($args = '') {
		global $post;
		
		/* default args */
		$defaults = array (
			'ID' => $post->ID,
			'thumbnail' => true,
			'thumbnail_size' => '480x300',
			'title' => true,
			'meta' => true,
			'excerpt' => true,
			'footer' => true,
			'class' => ''
		);
		
		$x = wp_parse_args ( $args, $defaults );
		$post_id = $x['ID'];
		$thumbnail = $x['thumbnail'];
		$thumbnail_size = $x['thumbnail_size'];
		$title = $x['title'];
		$meta = $x['meta'];
		$excerpt = $x['excerpt'];
		$footer = $x['footer'];
		$class = $x['class'];
		?>
        
        <article <?php post_class('entry '. $class); ?> id="post-<?php echo $post_id; ?>">
            <?php 
			if($thumbnail) :
				$post_format = get_post_format($post->ID);
				switch($post_format) :
					
					case 'gallery' :
						echo '<div class="entry-asset thumb-slider flexslider">';
						echo '<ul class="slides">'.freshthemes_print_gallery_images('size='.$thumbnail_size.'&before=<li>&after=</li>&caption=0&lightbox=1').'</ul>'; 
						if(get_post_meta( $post_id, THEME_FX . 'enable_review', true ) == true) : freshthemes_print_review_badge($post_id);  endif;
						echo '</div>';
						break;
						
					case 'image' :
						if ( (function_exists('has_post_thumbnail')) && ( has_post_thumbnail()) ) :
						$full_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
						echo '<figure class="entry-asset">';
						echo '<a href="'.$full_image[0].'" title="'.the_title_attribute( 'echo=0' ).'" class="prettyPhoto">'.get_the_post_thumbnail( $post->ID, $thumbnail_size ).'</a>';
						if(get_post_meta( $post_id, THEME_FX . 'enable_review', true ) == true) : freshthemes_print_review_badge($post_id);  endif;
						echo '</figure><!-- .entry-asset -->';
						endif; 
						break;
						
					default :
						if ( (function_exists('has_post_thumbnail')) && ( has_post_thumbnail()) ) :
						echo '<figure class="entry-asset">';
						echo '<a href="'.get_permalink().'" title="'.the_title_attribute( 'echo=0' ).'" >'.get_the_post_thumbnail( $post->ID, $thumbnail_size ).'</a>';
						if(get_post_meta( $post_id, THEME_FX . 'enable_review', true ) == true) : freshthemes_print_review_badge($post_id);  endif;
						echo '</figure><!-- .entry-asset -->';
						endif; 
						break;
						
				endswitch;
			endif; 
			?>
            
            <header class="entry-header clearfix">
				<?php if($title) : ?>
                <h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( '%s',  THEME_FX ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
                <?php endif; ?>
                
				<?php if($meta) : ?>
                <div class="entry-meta"><?php the_time( get_option('date_format') ); _e(' - ', THEME_FX); the_time( get_option('time_format') ); ?></div>
                <?php endif; ?>
            </header>
            
			<?php if($excerpt) : ?>
            <section class="entry-summary clearfix">
                <?php the_excerpt(); ?>
            </section>
            <?php endif; ?>
        </article>
       <?php
		
	}

/*	Function to print entry as list.
 *	--------------------------------------------------------------------------- */	
	function freshthemes_print_entry_list($thumb = true, $class = '', $meta = true) {
		global $post;
		
		$format = get_post_format();
		
		switch($format){
			case 'audio' :
				$format_icon = 'icon-music';
				break;
			
			case 'image' :
				$format_icon = 'icon-camera';
				break;
			
			case 'gallery' :
				$format_icon = 'icon-picture';
				break;
				
			case 'video' :
				$format_icon = 'icon-play-circle';
				break;
				
			default:
				$format_icon = 'icon-pencil';
				break;
		}
		?>
		<li class="clearfix <?php echo $class; ?>">
			<article>
            	<?php if ( $thumb == true ): ?>
                <figure class="thumb">
					<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
                    <?php if ( (function_exists('has_post_thumbnail')) && (has_post_thumbnail()) ) : ?>
						<?php the_post_thumbnail( '70x70' ); ?>
					<?php else: ?>
                    	<i class="<?php echo $format_icon; ?>"></i>
					<?php endif; ?>
                    </a>
				</figure>
                <?php endif; ?>
                
				<h5><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" rel="bookmark"><?php the_title(); ?></a></h5>
                <?php if($meta == true ) : ?>
					<div class="meta meta-review">
						<?php if(get_post_meta( $post->ID, THEME_FX . 'enable_review', true )) freshthemes_print_review_badge($post->ID); ?> 
                       <?php the_time( get_option('date_format') ); ?>
                    </div>
                <?php endif; ?>
            </article>
		</li>
		<?php
	}
	
/*	Function to print social links.
 *	--------------------------------------------------------------------------- */	
	function freshthemes_social_links($class = '', $echo = false ) {
		$output = '';
		$social_array = array( 'facebook', 'twitter', 'rss' );
		
		$output .= '<ul class="social-links '.$class.'">';
		foreach ( $social_array as $key ) {
			if ( ft_get_option('social_'. $key )) :
				$output .= '<li class="'. $key .'"><a href="'. ft_get_option('social_'. $key ). '" target="_blank"><span class="icon-'. $key .'"></span></a></li>';
			endif;
		}
		$output .= '</ul><!-- .social-links -->';
		
		if($echo != true) : return $output; else : echo $output; endif;
	}
	
	
/*	Function to print entry as list.
 *	--------------------------------------------------------------------------- */	
	function freshthemes_calculate_score($num, $type, $star = false) {
		
		switch ($type) :
		
			case 'star' :
				if(!$star == false){
					if ( $num <= 2 ) $output = '<span title="1 star"><i class="icon-star"></i><i class="icon-star-empty"></i><i class="icon-star-empty"></i><i class="icon-star-empty"></i><i class="icon-star-empty"></i></span>';
					if ( $num > 2 && $num <= 4 ) 
					$output = '<span title="2 stars"><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star-empty"></i><i class="icon-star-empty"></i><i class="icon-star-empty"></i></span>';
					if ( $num > 4 && $num <= 6 )
					$output = '<span title="3 stars"><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star-empty"></i><i class="icon-star-empty"></i></span>';
					if ( $num > 6 && $num <= 8 ) 
					$output = '<span title="4 stars"><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star-empty"></i></span>';
					if ( $num > 8 && $num <= 10 ) 
					$output = '<span title="5 stars"><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star"></i><i class="icon-star"></i></span>';
				} else {
					$output = $num;
				}
				break;
			
			case 'letter' :
				if ( $num <= 2 ) $output = 'E';
				if ( $num > 2 && $num <= 4 ) $output = 'D';
				if ( $num > 4 && $num <= 6 ) $output = 'C';
				if ( $num > 6 && $num <= 8 ) $output = 'B';
				if ( $num > 8 && $num <= 10 ) $output = 'A';
				break;
			
			case 'percent';
				$output = $num * 10 . '%';
				break;
			
			case 'number';
				$output = $num;
				break;
			
		endswitch;
		
		return $output;
	}
	
/*	Function to Display Review Box
 *	--------------------------------------------------------------------------- */
	function freshthemes_print_review_box($post_id, $class, $echo = true) {
		
		$review_box_title = get_post_meta( $post_id, THEME_FX . 'review_box_title', true );
		$review_box_total_score_label = get_post_meta( $post_id, THEME_FX . 'review_box_total_score_label', true );

		$rating_type = get_post_meta( $post_id, THEME_FX . 'rating_type', true );
		$rating_criteria = get_post_meta( $post_id, THEME_FX . 'rating_criteria', true );
		$rating_criteria_count =  count($rating_criteria);
		
		$output = '';
		$output .= '<div id="review-box" class="'.$class.'">';
		$output .= '<h5>'.$review_box_title.'</h5>';
		$output .= '<ul>';
			foreach ($rating_criteria as $criteria) {
				$percentage_score = $criteria['score'] * 10;
				
				if($criteria['c_label'])
				$output .= '<li><div class="review-criteria-score clearfix"><span class="right">'.$criteria['c_label'].'</span><span class="left">'.freshthemes_calculate_score($criteria['score'], $rating_type, true).'</span></div>';
				$output .= '<div class="review-criteria-bar-container"><div class="review-criteria-bar" style="width:'.$percentage_score.'%"></div></div></li>';
				
			}
		$output .= '</ul>';
		
		$output .= '<div class="review-total-score clearfix">';
			$score_array = array();
			foreach ($rating_criteria as $criteria) {
				$score_array []= $criteria['score'];
			}
			$final_score = array_sum($score_array);
			$final_score = $final_score / $rating_criteria_count;
			$final_score = number_format($final_score, 1, '.', '');
			
			$output .='<span class="right align-right">'.$review_box_total_score_label.'</span>';
		    $output .='<span class="left review-total-score-box type-'.$rating_type.'">'. freshthemes_calculate_score($final_score, $rating_type, true).'</span>';
    $output .= '</div>';
    
		$output .= '</div><!-- REVIEW_BOX -->';
		
		if($echo == 'true') :
		echo $output;
		else :
		return $output;
		endif;
	}
	
/*	Function to Display Review Badge
 *	--------------------------------------------------------------------------- */
	function freshthemes_print_review_badge($post_id, $echo = true) {
		
		$rating_type = get_post_meta( $post_id, THEME_FX . 'rating_type', true );
		$rating_criteria = get_post_meta( $post_id, THEME_FX . 'rating_criteria', true );
		$rating_criteria_count =  count($rating_criteria);
		
		$output = '';
		$score_array = array();
		
		if($rating_criteria){
			foreach ($rating_criteria as $criteria) {
				$score_array []= $criteria['score'];
			}
		}
		
		$final_score = array_sum($score_array);
		$final_score = $final_score / $rating_criteria_count;
		$final_score = number_format($final_score, 1, '.', '');
		
		$output = '<div class="review-badge review-badge-'.$rating_type.'">'.freshthemes_calculate_score($final_score, $rating_type, true).'</div>';
    
		if($echo == 'true') :
		echo $output;
		else :
		return $output;
		endif;
	}
	
/**	
 *	Enqueue Google fonts
 * 	------------------------------------------------------------------------------------------------------ */
	function freshthemes_typography_enqueue_google_font($font) {
		$font = explode(',', $font);
		$font = $font[0];
		
		if ($font == 'Arimo') $font = 'Arimo:400,700';
		if ($font == 'Arvo') $font = 'Arvo:400,700';
		if ($font == 'Asap') $font = 'Asap:400,700';
		if ($font == 'Bitter') $font = 'Bitter:400,700';
		if ($font == 'Cabin') $font = 'Cabin:400,500,600,700';
		if ($font == 'Cantarell') $font = 'Cantarell:400,700';
		if ($font == 'Droid Sans') $font = 'Droid Sans:400,700';
		if ($font == 'Droid Serif') $font = 'Droid Serif:400,700';
		if ($font == 'Josefin Sans') $font = 'Josefin Sans:300,400,600,700';
		if ($font == 'Kreon') $font = 'Kreon:300,400,700';
		if ($font == 'Lato') $font = 'Lato:300,400,700';
		if ($font == 'Lora') $font = 'Lora:400,700';
		if ($font == 'Merriweather') $font = 'Merriweather:300,400,700';
		if ($font == 'Nobile') $font = 'Nobile:700,400';
		if ($font == 'Nunito') $font = 'Nunito:300,400,700';
		if ($font == 'Open Sans') $font = 'Open Sans:400,300,600,700';
		if ($font == 'Oswald') $font = 'Oswald:300,400,700';
		if ($font == 'Philosopher') $font = 'Philosopher:400,700';
		if ($font == 'Play') $font = 'Play:400,700';
		if ($font == 'PT Sans') $font = 'PT Sans:400,700';
		if ($font == 'PT Serif') $font = 'PT Serif:400,700';
		if ($font == 'Rokkitt') $font = 'Rokkitt:400,700';
		if ($font == 'Source Sans Pro') $font = 'Source Sans Pro:300,400,600,700';
		if ($font == 'Ubuntu') $font = 'Ubuntu:300,400,500,700';
		if ($font == 'Vollkorn') $font = 'Vollkorn:400,700';
		if ($font == 'Yanone Kaffeesatz') $font = 'Yanone Kaffeesatz:300,400,700';
		
		$font = str_replace(' ', '+', $font);
		$font_id = str_replace(array(' ', '+', ':', ',', 'italic', '300', '400', '500', '600', '700'), '', $font);
		
	}
	
/*	Post/page Custom Background
 *	--------------------------------------------------------------------------- */	
	function freshthemes_custom_background($id) {
		$output = '';
		
		$image = get_post_meta( $id, THEME_FX . 'background_image', true );
		$type = get_post_meta( $id, THEME_FX . 'custom_background', true );
		$color = get_post_meta( $id, THEME_FX . 'background_color', true );
		$repeat = get_post_meta( $id, THEME_FX . 'background_repeat', true );
		$position = get_post_meta( $id, THEME_FX . 'background_position', true );
		$attachment = get_post_meta( $id, THEME_FX . 'background_attachment', true );
		
		if($type == 'backstrech') :
			$output = '<script>var BACKSTRECH_IMG = "'.$image.'";</script>';
		elseif($type == 'normal') :
			$output .= '<style>';
			$output .= 'body{';
			
				if($color) 
				$output .= 'background-color:'.$color.';';
				if($image) 
				$output .= 'background-image:url("'.$image.'");';
				if($repeat) 
				$output .= 'background-repeat:'.$repeat.';';
				if($position) 
				$output .= 'background-position:'.$position.';';
				if($attachment) 
				$output .= 'background-color:'.$attachment.';';
				
			$output .= '}';
			$output .= '</style>';
		else :
			$output = '';
		endif;
		
		return $output;
	}
	
/* 	Add Favicon
 * 	------------------------------------------------------------------------------------------------------ */
	function freshthemes_add_favicon() {
		// custom favicon.
		$custom_favicon = ft_get_option('custom_favicon');
		
		if (!$custom_favicon == '') {
			echo '<link rel="shortcut icon" href="'. $custom_favicon .'"/>'."\n";
		}
	}
	
	add_action( 'wp_head', 'freshthemes_add_favicon' );
	
/* 	Add Analitycs
 * 	------------------------------------------------------------------------------------------------------ */
	function freshthemes_add_tracking_code() {
		echo ft_get_option('tracking_code') . "\n";
	}
	
	add_action( 'wp_head', 'freshthemes_add_tracking_code' );

/*	Append scripts and styles to wp_footer
 *	--------------------------------------------------------------------------- */	
	function freshthemes_wp_footer_hook(){
		global $post;
		
		if( ft_get_option('want_backstrech') ) 
		echo '<script>var BACKSTRECH_IMG = "'.ft_get_option('backstrech_img').'";</script>';
		
		if(is_singular()) :
		echo freshthemes_custom_background($post->ID); 
		endif;
	}
	
	add_action('wp_footer', 'freshthemes_wp_footer_hook');
	
/*	Date translateable.
 *	--------------------------------------------------------------------------- */	
	function freshthemes_date($format, $timestamp = null) {
		$param_D = array('', __('دوشنبه', THEME_FX), __('سه‌شنبه', THEME_FX), __('چهارشنبه', THEME_FX), __('پنجشنبه', THEME_FX), __('جمعه', THEME_FX), __('شنبه', THEME_FX), __('یکشنبه', THEME_FX));
		
		$param_l = array('', __('دوشنبه', THEME_FX), __('سه‌شنبه', THEME_FX), __('چهارشنبه', THEME_FX), __('پنجشنبه', THEME_FX), __('جمعه', THEME_FX), __('شنبه', THEME_FX), __('یکشنبه', THEME_FX));
		
		$param_F = array('', __('ژانویه', THEME_FX), __('فبریه', THEME_FX), __('مارچ', THEME_FX), __('آپریل', THEME_FX), __('می', THEME_FX), __('جون', THEME_FX), __('جولای', THEME_FX), __('آگوست', THEME_FX), __('سپتامبر', THEME_FX), __('اکتبر', THEME_FX), __('نوامبر', THEME_FX), __('دسامبر', THEME_FX));
		
		$param_M = array('', __('ژانویه', THEME_FX), __('فبریه', THEME_FX), __('مارچ', THEME_FX), __('آپریل', THEME_FX), __('می', THEME_FX), __('جون', THEME_FX), __('جولای', THEME_FX), __('آگوست', THEME_FX), __('سپتامبر', THEME_FX), __('اکتبر', THEME_FX), __('نوامبر', THEME_FX), __('دسامبر', THEME_FX));
	
		$return = '';
		if(is_null($timestamp)) { $timestamp = mktime(); }
		for($i = 0, $len = strlen($format); $i < $len; $i++) {
			switch($format[$i]) {
				case '\\' : // fix.slashes
					$i++;
					$return .= isset($format[$i]) ? $format[$i] : '';
					break;
				case 'D' :
					$return .= $param_D[date('N', $timestamp)];
					break;
				case 'l' :
					$return .= $param_l[date('N', $timestamp)];
					break;
				case 'F' :
					$return .= $param_F[date('n', $timestamp)];
					break;
				case 'M' :
					$return .= $param_M[date('n', $timestamp)];
					break;
				default :
					$return .= date($format[$i], $timestamp);
					break;
			}
		}
		return $return;
	}